# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: internal_env.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'internal_env.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from . import env_pb2 as env__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12internal_env.proto\x12\trlmesh.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\tenv.proto\"\xe1\x01\n\x13InternalClientHello\x12\x0f\n\x07package\x18\x01 \x01(\t\x12\x0e\n\x06gym_id\x18\x02 \x01(\t\x12\x10\n\x08num_envs\x18\x03 \x01(\x05\x12\x11\n\x04seed\x18\x04 \x01(\x03H\x00\x88\x01\x01\x12\'\n\x06kwargs\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07sess_id\x18\n \x01(\t\x12\x17\n\x0frestricted_mode\x18\x0b \x01(\x08\x12(\n\x08recorder\x18\x0c \x01(\x0e\x32\x16.rlmesh.v1.EnvRecorderB\x07\n\x05_seed\"y\n\x11InternalClientMsg\x12/\n\x05hello\x18\x01 \x01(\x0b\x32\x1e.rlmesh.v1.InternalClientHelloH\x00\x12+\n\x0bproxied_msg\x18\x02 \x01(\x0b\x32\x14.rlmesh.v1.ClientMsgH\x00\x42\x06\n\x04kind\"\xa4\x01\n\x19InternalSaveHighlightsReq\x12\x0f\n\x07sess_id\x18\x01 \x01(\t\x12\x0f\n\x07package\x18\x02 \x01(\t\x12\x0e\n\x06gym_id\x18\x03 \x01(\t\x12\x10\n\x08num_envs\x18\x04 \x01(\x05\x12\x11\n\x04seed\x18\x05 \x01(\x03H\x00\x88\x01\x01\x12\'\n\x06kwargs\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\x07\n\x05_seed\";\n\x12HighlightedEpisode\x12\x11\n\tvideo_key\x18\x01 \x01(\t\x12\x12\n\nvideo_path\x18\x02 \x01(\t\"L\n\x19InternalSaveHighlightsRes\x12/\n\x08\x65pisodes\x18\x01 \x03(\x0b\x32\x1d.rlmesh.v1.HighlightedEpisode*K\n\x0b\x45nvRecorder\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06\x41\x43TION\x10\x02\x12\n\n\x06MINARI\x10\x03\x12\t\n\x05\x46RAME\x10\x04\x32\xbc\x01\n\x12InternalEnvService\x12\x41\n\x07\x43onnect\x12\x1c.rlmesh.v1.InternalClientMsg\x1a\x14.rlmesh.v1.ServerMsg(\x01\x30\x01\x12\x63\n\x15RecordPreviousSession\x12$.rlmesh.v1.InternalSaveHighlightsReq\x1a$.rlmesh.v1.InternalSaveHighlightsResB\x0fZ\rrlmesh/pkg/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'internal_env_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rrlmesh/pkg/pb'
  _globals['_ENVRECORDER']._serialized_start=731
  _globals['_ENVRECORDER']._serialized_end=806
  _globals['_INTERNALCLIENTHELLO']._serialized_start=75
  _globals['_INTERNALCLIENTHELLO']._serialized_end=300
  _globals['_INTERNALCLIENTMSG']._serialized_start=302
  _globals['_INTERNALCLIENTMSG']._serialized_end=423
  _globals['_INTERNALSAVEHIGHLIGHTSREQ']._serialized_start=426
  _globals['_INTERNALSAVEHIGHLIGHTSREQ']._serialized_end=590
  _globals['_HIGHLIGHTEDEPISODE']._serialized_start=592
  _globals['_HIGHLIGHTEDEPISODE']._serialized_end=651
  _globals['_INTERNALSAVEHIGHLIGHTSRES']._serialized_start=653
  _globals['_INTERNALSAVEHIGHLIGHTSRES']._serialized_end=729
  _globals['_INTERNALENVSERVICE']._serialized_start=809
  _globals['_INTERNALENVSERVICE']._serialized_end=997
# @@protoc_insertion_point(module_scope)
