# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agt_internal.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'agt_internal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gt_internal.proto\x12\trlmesh.v1\"\x10\n\x0eHealthcheckReq\" \n\rHealthcheckOk\x12\x0f\n\x07message\x18\x01 \x01(\t2V\n\x10InternalAgentAPI\x12\x42\n\x0bHealthcheck\x12\x19.rlmesh.v1.HealthcheckReq\x1a\x18.rlmesh.v1.HealthcheckOkB\x0fZ\rrlmesh/pkg/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agt_internal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rrlmesh/pkg/pb'
  _globals['_HEALTHCHECKREQ']._serialized_start=33
  _globals['_HEALTHCHECKREQ']._serialized_end=49
  _globals['_HEALTHCHECKOK']._serialized_start=51
  _globals['_HEALTHCHECKOK']._serialized_end=83
  _globals['_INTERNALAGENTAPI']._serialized_start=85
  _globals['_INTERNALAGENTAPI']._serialized_end=171
# @@protoc_insertion_point(module_scope)
