# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cp_internal.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cp_internal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import gym_pb2 as gym__pb2
from . import env_pb2 as env__pb2
from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63p_internal.proto\x12\trlmesh.v1\x1a\tgym.proto\x1a\tenv.proto\x1a\rsession.proto\"?\n\x1aInternalDescribeSessionReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"\xb9\x01\n\x1aInternalDescribeSessionRes\x12\x1f\n\x03\x65nv\x18\x01 \x01(\x0b\x32\x12.rlmesh.v1.EnvSpec\x12\x10\n\x08num_envs\x18\x02 \x01(\x05\x12\x11\n\x04seed\x18\x03 \x01(\x03H\x00\x88\x01\x01\x12$\n\x04type\x18\n \x01(\x0e\x32\x16.rlmesh.v1.SessionType\x12&\n\x05state\x18\x0b \x01(\x0e\x32\x17.rlmesh.v1.SessionStateB\x07\n\x05_seed\"\\\n\rSessionResult\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x10\n\x08\x64uration\x18\x02 \x01(\x02\x12*\n\x08\x65pisodes\x18\x03 \x03(\x0b\x32\x18.rlmesh.v1.EpisodeResult\"\xc7\x01\n\x18InternalUpdateSessionReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12&\n\x05state\x18\x03 \x01(\x0e\x32\x17.rlmesh.v1.SessionState\x12-\n\x06result\x18\x04 \x01(\x0b\x32\x18.rlmesh.v1.SessionResultH\x00\x88\x01\x01\x12\x17\n\nuser_token\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_resultB\r\n\x0b_user_token\"\xd8\x01\n\x18InternalUpdateSessionRes\x12#\n\x07session\x18\x01 \x01(\x0b\x32\x12.rlmesh.v1.Session\x12[\n\x15highlight_upload_urls\x18\x02 \x03(\x0b\x32<.rlmesh.v1.InternalUpdateSessionRes.HighlightUploadUrlsEntry\x1a:\n\x18HighlightUploadUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xd5\x01\n\x17InternalControlPlaneAPI\x12_\n\x0f\x44\x65scribeSession\x12%.rlmesh.v1.InternalDescribeSessionReq\x1a%.rlmesh.v1.InternalDescribeSessionRes\x12Y\n\rUpdateSession\x12#.rlmesh.v1.InternalUpdateSessionReq\x1a#.rlmesh.v1.InternalUpdateSessionResB\x0fZ\rrlmesh/pkg/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cp_internal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rrlmesh/pkg/pb'
  _globals['_INTERNALUPDATESESSIONRES_HIGHLIGHTUPLOADURLSENTRY']._loaded_options = None
  _globals['_INTERNALUPDATESESSIONRES_HIGHLIGHTUPLOADURLSENTRY']._serialized_options = b'8\001'
  _globals['_INTERNALDESCRIBESESSIONREQ']._serialized_start=69
  _globals['_INTERNALDESCRIBESESSIONREQ']._serialized_end=132
  _globals['_INTERNALDESCRIBESESSIONRES']._serialized_start=135
  _globals['_INTERNALDESCRIBESESSIONRES']._serialized_end=320
  _globals['_SESSIONRESULT']._serialized_start=322
  _globals['_SESSIONRESULT']._serialized_end=414
  _globals['_INTERNALUPDATESESSIONREQ']._serialized_start=417
  _globals['_INTERNALUPDATESESSIONREQ']._serialized_end=616
  _globals['_INTERNALUPDATESESSIONRES']._serialized_start=619
  _globals['_INTERNALUPDATESESSIONRES']._serialized_end=835
  _globals['_INTERNALUPDATESESSIONRES_HIGHLIGHTUPLOADURLSENTRY']._serialized_start=777
  _globals['_INTERNALUPDATESESSIONRES_HIGHLIGHTUPLOADURLSENTRY']._serialized_end=835
  _globals['_INTERNALCONTROLPLANEAPI']._serialized_start=838
  _globals['_INTERNALCONTROLPLANEAPI']._serialized_end=1051
# @@protoc_insertion_point(module_scope)
