# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: env.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'env.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from . import gym_pb2 as gym__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tenv.proto\x12\trlmesh.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\tgym.proto\"E\n\x06Tensor\x12\x1f\n\x05\x64type\x18\x01 \x01(\x0e\x32\x10.rlmesh.v1.DType\x12\r\n\x05shape\x18\x02 \x03(\x03\x12\x0b\n\x03raw\x18\x03 \x01(\x0c\"\x19\n\x08ResetReq\x12\r\n\x05seeds\x18\x01 \x03(\x03\"-\n\x07StepReq\x12\"\n\x07\x61\x63tions\x18\x01 \x01(\x0b\x32\x11.rlmesh.v1.Tensor\"\x0b\n\tRenderReq\"\n\n\x08\x43loseReq\"\n\n\x08StateReq\"\xd1\x01\n\tClientMsg\x12$\n\x05reset\x18\x01 \x01(\x0b\x32\x13.rlmesh.v1.ResetReqH\x00\x12\"\n\x04step\x18\x02 \x01(\x0b\x32\x12.rlmesh.v1.StepReqH\x00\x12&\n\x06render\x18\x03 \x01(\x0b\x32\x14.rlmesh.v1.RenderReqH\x00\x12$\n\x05\x63lose\x18\x04 \x01(\x0b\x32\x13.rlmesh.v1.CloseReqH\x00\x12$\n\x05state\x18\x05 \x01(\x0b\x32\x13.rlmesh.v1.StateReqH\x00\x42\x06\n\x04kind\"Q\n\x07ResetOk\x12\x1e\n\x03obs\x18\x01 \x01(\x0b\x32\x11.rlmesh.v1.Tensor\x12&\n\x05infos\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xa5\x01\n\x06StepOk\x12\x1e\n\x03obs\x18\x01 \x01(\x0b\x32\x11.rlmesh.v1.Tensor\x12\"\n\x07rewards\x18\x02 \x01(\x0b\x32\x11.rlmesh.v1.Tensor\x12\x17\n\x0fterminated_mask\x18\x03 \x01(\x0c\x12\x16\n\x0etruncated_mask\x18\x04 \x01(\x0c\x12&\n\x05infos\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\",\n\x08RenderOk\x12 \n\x05\x66rame\x18\x01 \x01(\x0b\x32\x11.rlmesh.v1.Tensor\"V\n\rEpisodeResult\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x10\n\x08\x64uration\x18\x02 \x01(\x02\x12\x16\n\tvideo_key\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_video_key\"]\n\x07\x43loseOk\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x10\n\x08\x64uration\x18\x02 \x01(\x02\x12\x31\n\x0f\x65pisode_results\x18\x03 \x03(\x0b\x32\x18.rlmesh.v1.EpisodeResult\"\x1e\n\x0bServerError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xdc\x01\n\tServerMsg\x12&\n\x08reset_ok\x18\x01 \x01(\x0b\x32\x12.rlmesh.v1.ResetOkH\x00\x12$\n\x07step_ok\x18\x02 \x01(\x0b\x32\x11.rlmesh.v1.StepOkH\x00\x12(\n\trender_ok\x18\x03 \x01(\x0b\x32\x13.rlmesh.v1.RenderOkH\x00\x12&\n\x08\x63lose_ok\x18\x04 \x01(\x0b\x32\x12.rlmesh.v1.CloseOkH\x00\x12\'\n\x05\x65rror\x18\n \x01(\x0b\x32\x16.rlmesh.v1.ServerErrorH\x00\x42\x06\n\x04kind2G\n\nEnvService\x12\x39\n\x07\x43onnect\x12\x14.rlmesh.v1.ClientMsg\x1a\x14.rlmesh.v1.ServerMsg(\x01\x30\x01\x42\x0fZ\rrlmesh/pkg/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'env_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rrlmesh/pkg/pb'
  _globals['_TENSOR']._serialized_start=65
  _globals['_TENSOR']._serialized_end=134
  _globals['_RESETREQ']._serialized_start=136
  _globals['_RESETREQ']._serialized_end=161
  _globals['_STEPREQ']._serialized_start=163
  _globals['_STEPREQ']._serialized_end=208
  _globals['_RENDERREQ']._serialized_start=210
  _globals['_RENDERREQ']._serialized_end=221
  _globals['_CLOSEREQ']._serialized_start=223
  _globals['_CLOSEREQ']._serialized_end=233
  _globals['_STATEREQ']._serialized_start=235
  _globals['_STATEREQ']._serialized_end=245
  _globals['_CLIENTMSG']._serialized_start=248
  _globals['_CLIENTMSG']._serialized_end=457
  _globals['_RESETOK']._serialized_start=459
  _globals['_RESETOK']._serialized_end=540
  _globals['_STEPOK']._serialized_start=543
  _globals['_STEPOK']._serialized_end=708
  _globals['_RENDEROK']._serialized_start=710
  _globals['_RENDEROK']._serialized_end=754
  _globals['_EPISODERESULT']._serialized_start=756
  _globals['_EPISODERESULT']._serialized_end=842
  _globals['_CLOSEOK']._serialized_start=844
  _globals['_CLOSEOK']._serialized_end=937
  _globals['_SERVERERROR']._serialized_start=939
  _globals['_SERVERERROR']._serialized_end=969
  _globals['_SERVERMSG']._serialized_start=972
  _globals['_SERVERMSG']._serialized_end=1192
  _globals['_ENVSERVICE']._serialized_start=1194
  _globals['_ENVSERVICE']._serialized_end=1265
# @@protoc_insertion_point(module_scope)
