# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cp_public.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cp_public.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import gym_pb2 as gym__pb2
from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63p_public.proto\x12\trlmesh.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\tgym.proto\x1a\rsession.proto\"\x1e\n\x08WatchReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\"!\n\x0b\x44\x65scribeReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\"@\n\x0b\x44\x65scribeRes\x12\x1f\n\x03\x65nv\x18\x01 \x01(\x0b\x32\x12.rlmesh.v1.EnvSpec\x12\x10\n\x08num_envs\x18\x02 \x01(\x05\"#\n\rGetResultsReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\"_\n\rGetResultsRes\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x10\n\x08\x64uration\x18\x02 \x01(\x02\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x10\n\x0eListRegionsReq\"!\n\x0eListRegionsRes\x12\x0f\n\x07regions\x18\x01 \x03(\t\"\x15\n\x13ListEnvironmentsReq\"\x9e\x01\n\x13ListEnvironmentsRes\x12>\n\x08packages\x18\x01 \x03(\x0b\x32,.rlmesh.v1.ListEnvironmentsRes.PackagesEntry\x1aG\n\rPackagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.rlmesh.v1.PackageEnvs:\x02\x38\x01\"\x1e\n\x0bPackageEnvs\x12\x0f\n\x07\x65nv_ids\x18\x01 \x03(\t\"\x90\x02\n\x10\x43reateSessionReq\x12\x38\n\x0binteractive\x18\x01 \x01(\x0b\x32!.rlmesh.v1.InteractiveSessionSpecH\x00\x12\x45\n\x12internal_benchmark\x18\x02 \x01(\x0b\x32\'.rlmesh.v1.InternalBenchmarkSessionSpecH\x00\x12\x45\n\x12\x65xternal_benchmark\x18\x03 \x01(\x0b\x32\'.rlmesh.v1.ExternalBenchmarkSessionSpecH\x00\x12,\n\x05train\x18\x04 \x01(\x0b\x32\x1b.rlmesh.v1.TrainSessionSpecH\x00\x42\x06\n\x04kind2\xb2\x03\n\x15PublicControlPlaneAPI\x12\x43\n\x0bListRegions\x12\x19.rlmesh.v1.ListRegionsReq\x1a\x19.rlmesh.v1.ListRegionsRes\x12R\n\x10ListEnvironments\x12\x1e.rlmesh.v1.ListEnvironmentsReq\x1a\x1e.rlmesh.v1.ListEnvironmentsRes\x12@\n\rCreateSession\x12\x1b.rlmesh.v1.CreateSessionReq\x1a\x12.rlmesh.v1.Session\x12\x41\n\x0f\x44\x65scribeSession\x12\x16.rlmesh.v1.DescribeReq\x1a\x16.rlmesh.v1.DescribeRes\x12\x39\n\x0cWatchSession\x12\x13.rlmesh.v1.WatchReq\x1a\x12.rlmesh.v1.Session0\x01\x12@\n\nGetResults\x12\x18.rlmesh.v1.GetResultsReq\x1a\x18.rlmesh.v1.GetResultsResB\x0fZ\rrlmesh/pkg/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cp_public_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rrlmesh/pkg/pb'
  _globals['_LISTENVIRONMENTSRES_PACKAGESENTRY']._loaded_options = None
  _globals['_LISTENVIRONMENTSRES_PACKAGESENTRY']._serialized_options = b'8\001'
  _globals['_WATCHREQ']._serialized_start=89
  _globals['_WATCHREQ']._serialized_end=119
  _globals['_DESCRIBEREQ']._serialized_start=121
  _globals['_DESCRIBEREQ']._serialized_end=154
  _globals['_DESCRIBERES']._serialized_start=156
  _globals['_DESCRIBERES']._serialized_end=220
  _globals['_GETRESULTSREQ']._serialized_start=222
  _globals['_GETRESULTSREQ']._serialized_end=257
  _globals['_GETRESULTSRES']._serialized_start=259
  _globals['_GETRESULTSRES']._serialized_end=354
  _globals['_LISTREGIONSREQ']._serialized_start=356
  _globals['_LISTREGIONSREQ']._serialized_end=372
  _globals['_LISTREGIONSRES']._serialized_start=374
  _globals['_LISTREGIONSRES']._serialized_end=407
  _globals['_LISTENVIRONMENTSREQ']._serialized_start=409
  _globals['_LISTENVIRONMENTSREQ']._serialized_end=430
  _globals['_LISTENVIRONMENTSRES']._serialized_start=433
  _globals['_LISTENVIRONMENTSRES']._serialized_end=591
  _globals['_LISTENVIRONMENTSRES_PACKAGESENTRY']._serialized_start=520
  _globals['_LISTENVIRONMENTSRES_PACKAGESENTRY']._serialized_end=591
  _globals['_PACKAGEENVS']._serialized_start=593
  _globals['_PACKAGEENVS']._serialized_end=623
  _globals['_CREATESESSIONREQ']._serialized_start=626
  _globals['_CREATESESSIONREQ']._serialized_end=898
  _globals['_PUBLICCONTROLPLANEAPI']._serialized_start=901
  _globals['_PUBLICCONTROLPLANEAPI']._serialized_end=1335
# @@protoc_insertion_point(module_scope)
