# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: session.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'session.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsession.proto\x12\trlmesh.v1\x1a\x1cgoogle/protobuf/struct.proto\"\xda\x01\n\x16InteractiveSessionSpec\x12\x0e\n\x06gym_id\x18\x01 \x01(\t\x12\x10\n\x08num_envs\x18\x02 \x01(\x05\x12\'\n\x06kwargs\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\tlocations\x18\n \x03(\x0b\x32\x30.rlmesh.v1.InteractiveSessionSpec.LocationsEntry\x1a\x30\n\x0eLocationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x1e\n\x1cInternalBenchmarkSessionSpec\"\xc0\x01\n\x1c\x45xternalBenchmarkSessionSpec\x12\x0f\n\x07\x63omp_id\x18\x01 \x01(\t\x12\x12\n\nuser_token\x18\x02 \x01(\t\x12I\n\tlocations\x18\n \x03(\x0b\x32\x36.rlmesh.v1.ExternalBenchmarkSessionSpec.LocationsEntry\x1a\x30\n\x0eLocationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x12\n\x10TrainSessionSpec\"\xb5\x01\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\x12$\n\x04type\x18\x02 \x01(\x0e\x32\x16.rlmesh.v1.SessionType\x12&\n\x05state\x18\x03 \x01(\x0e\x32\x17.rlmesh.v1.SessionState\x12\x1b\n\x0equeue_position\x18\x04 \x01(\x03H\x00\x88\x01\x01\x12\x14\n\x07\x61\x64\x64ress\x18\n \x01(\tH\x01\x88\x01\x01\x42\x11\n\x0f_queue_positionB\n\n\x08_address*\x88\x01\n\x0cSessionState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06QUEUED\x10\x01\x12\x10\n\x0cPROVISIONING\x10\x02\x12\t\n\x05READY\x10\x03\x12\x0f\n\x0bIN_PROGRESS\x10\x04\x12\r\n\tCOMPLETED\x10\x05\x12\x0b\n\x07\x45RRORED\x10\x06\x12\x0b\n\x07TIMEOUT\x10\x07*o\n\x0bSessionType\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bINTERACTIVE\x10\x01\x12\x16\n\x12INTERNAL_BENCHMARK\x10\x02\x12\x16\n\x12\x45XTERNAL_BENCHMARK\x10\x03\x12\t\n\x05TRAIN\x10\x04\x42\x0fZ\rrlmesh/pkg/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'session_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rrlmesh/pkg/pb'
  _globals['_INTERACTIVESESSIONSPEC_LOCATIONSENTRY']._loaded_options = None
  _globals['_INTERACTIVESESSIONSPEC_LOCATIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXTERNALBENCHMARKSESSIONSPEC_LOCATIONSENTRY']._loaded_options = None
  _globals['_EXTERNALBENCHMARKSESSIONSPEC_LOCATIONSENTRY']._serialized_options = b'8\001'
  _globals['_SESSIONSTATE']._serialized_start=711
  _globals['_SESSIONSTATE']._serialized_end=847
  _globals['_SESSIONTYPE']._serialized_start=849
  _globals['_SESSIONTYPE']._serialized_end=960
  _globals['_INTERACTIVESESSIONSPEC']._serialized_start=59
  _globals['_INTERACTIVESESSIONSPEC']._serialized_end=277
  _globals['_INTERACTIVESESSIONSPEC_LOCATIONSENTRY']._serialized_start=229
  _globals['_INTERACTIVESESSIONSPEC_LOCATIONSENTRY']._serialized_end=277
  _globals['_INTERNALBENCHMARKSESSIONSPEC']._serialized_start=279
  _globals['_INTERNALBENCHMARKSESSIONSPEC']._serialized_end=309
  _globals['_EXTERNALBENCHMARKSESSIONSPEC']._serialized_start=312
  _globals['_EXTERNALBENCHMARKSESSIONSPEC']._serialized_end=504
  _globals['_EXTERNALBENCHMARKSESSIONSPEC_LOCATIONSENTRY']._serialized_start=229
  _globals['_EXTERNALBENCHMARKSESSIONSPEC_LOCATIONSENTRY']._serialized_end=277
  _globals['_TRAINSESSIONSPEC']._serialized_start=506
  _globals['_TRAINSESSIONSPEC']._serialized_end=524
  _globals['_SESSION']._serialized_start=527
  _globals['_SESSION']._serialized_end=708
# @@protoc_insertion_point(module_scope)
