# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gym.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'gym.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgym.proto\x12\trlmesh.v1\"n\n\x07\x42oxSpec\x12\x11\n\tunbounded\x18\x01 \x01(\x08\x12\x11\n\tlo_scalar\x18\x02 \x01(\x01\x12\x11\n\thi_scalar\x18\x03 \x01(\x01\x12\x14\n\x0clo_broadcast\x18\x04 \x03(\x01\x12\x14\n\x0chi_broadcast\x18\x05 \x03(\x01\"(\n\x0c\x44iscreteSpec\x12\t\n\x01n\x18\x01 \x01(\x03\x12\r\n\x05start\x18\x02 \x01(\x03\"\x1c\n\x0fMultiBinarySpec\x12\t\n\x01n\x18\x01 \x01(\x03\"!\n\x11MultiDiscreteSpec\x12\x0c\n\x04nvec\x18\x01 \x03(\x03\"C\n\x08TextSpec\x12\x12\n\nmin_length\x18\x01 \x01(\x03\x12\x12\n\nmax_length\x18\x02 \x01(\x03\x12\x0f\n\x07\x63harset\x18\x03 \x01(\t\">\n\x08\x44ictSpec\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12$\n\x06spaces\x18\x02 \x03(\x0b\x32\x14.rlmesh.v1.SpaceSpec\"1\n\tTupleSpec\x12$\n\x06spaces\x18\x01 \x03(\x0b\x32\x14.rlmesh.v1.SpaceSpec\"\x96\x03\n\tSpaceSpec\x12\"\n\x04kind\x18\x01 \x01(\x0e\x32\x14.rlmesh.v1.SpaceKind\x12\x1f\n\x05\x64type\x18\x02 \x01(\x0e\x32\x10.rlmesh.v1.DType\x12\r\n\x05shape\x18\x03 \x03(\x03\x12!\n\x03\x62ox\x18\n \x01(\x0b\x32\x12.rlmesh.v1.BoxSpecH\x00\x12+\n\x08\x64iscrete\x18\x0b \x01(\x0b\x32\x17.rlmesh.v1.DiscreteSpecH\x00\x12\x32\n\x0cmulti_binary\x18\x0c \x01(\x0b\x32\x1a.rlmesh.v1.MultiBinarySpecH\x00\x12\x36\n\x0emulti_discrete\x18\r \x01(\x0b\x32\x1c.rlmesh.v1.MultiDiscreteSpecH\x00\x12#\n\x04text\x18\x0e \x01(\x0b\x32\x13.rlmesh.v1.TextSpecH\x00\x12#\n\x04\x64ict\x18\x14 \x01(\x0b\x32\x13.rlmesh.v1.DictSpecH\x00\x12%\n\x05tuple\x18\x15 \x01(\x0b\x32\x14.rlmesh.v1.TupleSpecH\x00\x42\x08\n\x06\x64\x65tail\"T\n\tGymSpaces\x12!\n\x03obs\x18\x01 \x01(\x0b\x32\x14.rlmesh.v1.SpaceSpec\x12$\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x14.rlmesh.v1.SpaceSpec\"7\n\x0bGymMetadata\x12\x14\n\x0crender_modes\x18\x01 \x03(\t\x12\x12\n\nrender_fps\x18\x02 \x01(\x03\"z\n\x07\x45nvSpec\x12\x0f\n\x07package\x18\x01 \x01(\t\x12\x0e\n\x06gym_id\x18\x02 \x01(\t\x12$\n\x06spaces\x18\x04 \x01(\x0b\x32\x14.rlmesh.v1.GymSpaces\x12(\n\x08metadata\x18\x05 \x01(\x0b\x32\x16.rlmesh.v1.GymMetadata*Y\n\x05\x44Type\x12\x15\n\x11\x44TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05UINT8\x10\x01\x12\t\n\x05INT32\x10\x02\x12\t\n\x05INT64\x10\x03\x12\x0b\n\x07\x46LOAT32\x10\x04\x12\x0b\n\x07\x46LOAT64\x10\x05*|\n\tSpaceKind\x12\x15\n\x11UNSPECIFIED_SPACE\x10\x00\x12\x07\n\x03\x42OX\x10\x01\x12\x0c\n\x08\x44ISCRETE\x10\x02\x12\x0f\n\x0bMULTIBINARY\x10\x04\x12\x11\n\rMULTIDISCRETE\x10\x03\x12\x08\n\x04TEXT\x10\x06\x12\t\n\x05TUPLE\x10\n\x12\x08\n\x04\x44ICT\x10\x0b\x42\x0fZ\rrlmesh/pkg/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gym_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\rrlmesh/pkg/pb'
  _globals['_DTYPE']._serialized_start=1103
  _globals['_DTYPE']._serialized_end=1192
  _globals['_SPACEKIND']._serialized_start=1194
  _globals['_SPACEKIND']._serialized_end=1318
  _globals['_BOXSPEC']._serialized_start=24
  _globals['_BOXSPEC']._serialized_end=134
  _globals['_DISCRETESPEC']._serialized_start=136
  _globals['_DISCRETESPEC']._serialized_end=176
  _globals['_MULTIBINARYSPEC']._serialized_start=178
  _globals['_MULTIBINARYSPEC']._serialized_end=206
  _globals['_MULTIDISCRETESPEC']._serialized_start=208
  _globals['_MULTIDISCRETESPEC']._serialized_end=241
  _globals['_TEXTSPEC']._serialized_start=243
  _globals['_TEXTSPEC']._serialized_end=310
  _globals['_DICTSPEC']._serialized_start=312
  _globals['_DICTSPEC']._serialized_end=374
  _globals['_TUPLESPEC']._serialized_start=376
  _globals['_TUPLESPEC']._serialized_end=425
  _globals['_SPACESPEC']._serialized_start=428
  _globals['_SPACESPEC']._serialized_end=834
  _globals['_GYMSPACES']._serialized_start=836
  _globals['_GYMSPACES']._serialized_end=920
  _globals['_GYMMETADATA']._serialized_start=922
  _globals['_GYMMETADATA']._serialized_end=977
  _globals['_ENVSPEC']._serialized_start=979
  _globals['_ENVSPEC']._serialized_end=1101
# @@protoc_insertion_point(module_scope)
